@@ -331,7 +331,7 @@ class cmake_old(make):
         Run the tests in a Gaudi/LHCb project using CMT.
         '''
         kwargs['args'] = ['BUILDDIR=build'] + kwargs.get('args', [])
-        flags = ["--repeat until-pass:3"]
+        flags = []  # ["--repeat until-pass:3"]
         if "jobs" in kwargs:
             flags.append("-j{}".format(kwargs.pop("jobs")))
 
@@ -578,7 +578,8 @@ class cmake_new(object):
             # no point trying to run the tests if we failed to configure
             return config_result
 
-        cmd = ['ctest', '-T', 'test', '--repeat', 'until-pass:3']
+        cmd = ['ctest', '-T', 'test']
+        # cmd.extend(['--repeat', 'until-pass:3'])
         if 'jobs' in kwargs:
             cmd.extend(['-j', str(kwargs['jobs'])])
         test_result = self._call(
