@@ -400,10 +400,11 @@ string(REPLACE "$${NIGHTLY_BUILD_ROOT}" "$${CMAKE_CURRENT_LIST_DIR}"
         opts = self.options
 
         self._setup(json_type='build-result', summary_base='build')
-        self._file_excl_rex = re.compile((r'^(InstallArea)|(build\.{0})|({0})|'
-                                          r'(\.git)|(\.svn)|'
-                                          r'(\.{0}\.d)|(Testing)|(.*\.pyc)|'
-                                          r'(cov-out)$').format(self.platform))
+        self._file_excl_rex = re.compile(
+            (r'^(InstallArea)|(build(\.{0})?)|({0})|'
+             r'(\.git)|(\.svn)|'
+             r'(\.{0}\.d)|(Testing)|(.*\.pyc)|'
+             r'(cov-out)$').format(self.platform))
 
         # See LBCORE-637 (we do not want ccache for releases)
         if opts.use_ccache and os.environ.get('flavour') == 'release':
@@ -618,7 +619,7 @@ string(REPLACE "$${NIGHTLY_BUILD_ROOT}" "$${CMAKE_CURRENT_LIST_DIR}"
                         set(open(join(summary_dir, 'sources.list'))))
                     pack([
                         os.path.relpath(f.strip(), self.build_dir)
-                        for f in sorted(to_pack_list)
+                        for f in sorted(to_pack_list) if f.strip()
                     ],
                          shr_pack,
                          cwd=self.build_dir,
