@@ -116,6 +116,9 @@ def genConfig(slot='lhcb-release',
                 'export': True
             }
         }
+        # LCG might be in the list, but just as a hint
+        if proj.lower() == 'lcg':
+            project['disabled'] = True
 
         added.append(proj)
 
@@ -152,8 +155,9 @@ def genConfig(slot='lhcb-release',
         'error_exceptions': ERR_EXCEPT,
         'warning_exceptions': WARN_EXCEPT,
         'platforms': platforms or [],
-        'cache_entries': {
-            'GAUDI_STRICT_VERSION_CHECK': True
+        'cmake_cache': {
+            'GAUDI_STRICT_VERSION_CHECK': True,
+            "GAUDI_LEGACY_CMAKE_SUPPORT": True,
         },
     }
 
