@@ -1168,10 +1168,10 @@ def gitlabProjectExists(project):
 
 MR_COMMENT_TMPLS = {
     True: ('Validation started with [{slot}#{id}]('
-           'https://lhcb-nightlies.web.cern.ch/nightly/{slot}/build/{id}/)'),
-    False: ('Automatic merge failed in [{slot}#{id}]('
-            'https://lhcb-nightlies.web.cern.ch/logs/checkout/nightly/'
-            '{slot}/{id}/{proj}/)'),
+           'https://lhcb-nightlies.web.cern.ch/nightly/{slot}/{id}/)'),
+    False:
+    ('Automatic merge failed in [{slot}#{id}]('
+     'https://lhcb-nightlies.web.cern.ch/nightly/{slot}/{id}/{proj}/checkout'),
 }
 
 
